# Generated by roxygen2: do not edit by hand

S3method(add_cif,default)
S3method(add_hazard,default)
S3method(arrange,ped)
S3method(as.data.frame,crps)
S3method(as_ped,data.frame)
S3method(as_ped,list)
S3method(as_ped,nested_fdf)
S3method(as_ped,pamm)
S3method(as_ped,ped)
S3method(distinct,ped)
S3method(filter,ped)
S3method(full_join,ped)
S3method(get_cumu_coef,aalen)
S3method(get_cumu_coef,cox.aalen)
S3method(get_cumu_coef,gam)
S3method(get_intervals,default)
S3method(get_laglead,data.frame)
S3method(get_laglead,default)
S3method(gg_laglead,LL_df)
S3method(gg_laglead,default)
S3method(gg_laglead,nested_fdf)
S3method(gg_smooth,default)
S3method(group_by,ped)
S3method(inner_join,ped)
S3method(int_info,data.frame)
S3method(int_info,default)
S3method(int_info,pamm)
S3method(int_info,ped)
S3method(left_join,ped)
S3method(make_newdata,default)
S3method(make_newdata,fped)
S3method(make_newdata,ped)
S3method(mutate,ped)
S3method(nest_tdc,default)
S3method(nest_tdc,list)
S3method(ped_info,ped)
S3method(plot,pamm)
S3method(predictSurvProb,pamm)
S3method(print,pamm)
S3method(rename,ped)
S3method(right_join,ped)
S3method(sample_frac,ped)
S3method(sample_info,data.frame)
S3method(sample_info,fped)
S3method(sample_info,ped)
S3method(sample_n,ped)
S3method(select,ped)
S3method(slice,ped)
S3method(summarise,ped)
S3method(summarize,ped)
S3method(summary,pamm)
S3method(tidy_fixed,coxph)
S3method(tidy_fixed,gam)
S3method(transmute,ped)
S3method(ungroup,ped)
export("%>%")
export(GeomHazard)
export(GeomStepHazard)
export(GeomStepribbon)
export(GeomSurv)
export(add_cif)
export(add_counterfactual_transitions)
export(add_cumu_hazard)
export(add_hazard)
export(add_surv_prob)
export(add_tdc)
export(add_term)
export(add_trans_prob)
export(arrange)
export(as_ped)
export(as_ped_multistate)
export(combine_df)
export(cumulative)
export(distinct)
export(fcumu)
export(filter)
export(full_join)
export(geom_hazard)
export(geom_stephazard)
export(geom_stepribbon)
export(geom_surv)
export(get_cumu_coef)
export(get_cumu_eff)
export(get_intervals)
export(get_laglead)
export(get_partial_ll)
export(get_plotinfo)
export(get_terms)
export(gg_cumu_eff)
export(gg_fixed)
export(gg_laglead)
export(gg_partial)
export(gg_partial_ll)
export(gg_re)
export(gg_slice)
export(gg_smooth)
export(gg_tensor)
export(group_by)
export(inner_join)
export(int_info)
export(is.pamm)
export(is.ped)
export(left_join)
export(make_newdata)
export(mutate)
export(nest_tdc)
export(pamm)
export(ped_info)
export(rename)
export(right_join)
export(sample_frac)
export(sample_info)
export(sample_n)
export(select)
export(seq_range)
export(sim_pexp)
export(slice)
export(split_data)
export(summarise)
export(tidy_fixed)
export(tidy_re)
export(tidy_smooth)
export(tidy_smooth2d)
export(transmute)
export(ungroup)
import(Formula)
import(checkmate)
import(dplyr)
import(ggplot2)
import(mgcv)
import(purrr)
import(survival)
importFrom(Formula,Formula)
importFrom(checkmate,assert_atomic_vector)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_class)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,test_data_frame)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,slice)
importFrom(ggplot2,GeomLine)
importFrom(ggplot2,GeomRibbon)
importFrom(ggplot2,GeomStep)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,layer)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(graphics,plot)
importFrom(lazyeval,f_eval)
importFrom(magrittr,"%>%")
importFrom(mgcv,predict.bam)
importFrom(mgcv,predict.gam)
importFrom(mvtnorm,rmvnorm)
importFrom(pec,predictSurvProb)
importFrom(purrr,compose)
importFrom(purrr,cross_df)
importFrom(purrr,discard)
importFrom(purrr,flatten)
importFrom(purrr,invoke_map)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_dfr)
importFrom(purrr,map_dfr)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,reduce)
importFrom(purrr,set_names)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(rlang,UQ)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,quo_name)
importFrom(rlang,quos)
importFrom(rlang,sym)
importFrom(scam,predict.scam)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,poisson)
importFrom(stats,ppoints)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rexp)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(tibble,as_tibble)
importFrom(tidyr,complete)
importFrom(tidyr,crossing)
importFrom(tidyr,expand_grid)
importFrom(tidyr,gather)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,replace_na)
importFrom(tidyr,unnest)
importFrom(vctrs,vec_c)
