% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers.R
\name{modus}
\alias{modus}
\title{Calculate the modus}
\usage{
modus(var)
}
\arguments{
\item{var}{A atomic vector}
}
\description{
Calculate the modus
}
\keyword{internal}
