% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sim-pexp.R
\name{sim_pexp_cr}
\alias{sim_pexp_cr}
\title{Simulate data for competing risks scenario}
\usage{
sim_pexp_cr(formula, data, cut)
}
\description{
Simulate data for competing risks scenario
}
\keyword{internal}
